pymodaq_plugins_piezoconcept (PiezoConcept Stages)
##################################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_piezoconcept.svg
   :target: https://pypi.org/project/pymodaq_plugins_piezoconcept/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/CEMES-CNRS/pymodaq_plugins_piezoconcept/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/CEMES-CNRS/pymodaq_plugins_piezoconcept

PyMoDAQ plugin for actuators from Piezoconcept (Tested on the Bio2.100 XY stage). Include a version of the
controller firmware emulating functions from PhysikInstrumente


Authors
=======

* Sebastien J. Weber

Instruments
===========
Below is the list of instruments included in this plugin

Actuators
+++++++++

* **PiezoConcept** : piezoconcept stages (tested on BIO2.100) using the usual serial commands
* **PiezoConceptPI**: Special firmware to emulate functions form the GCS2 library from Physik Instrumente
